// File:  SubMenusDemos\SubMenusDemo.java

// Show how to set up sub-menus and a key handler

import java.awt.*;
import java.awt.event.*;

public class SubMenusDemo extends Frame {

    // Set up the Menu Bar; initialize the File menu; set up a key handler
    public SubMenusDemo() {
        super("SubMenusDemo");
        setLayout(new FlowLayout());
        setMenuBar(mBar);
        initFileMenu();

        // Use a Canvas to "hang" the key handler onto
        // (You've got to have SOMETHING that will allow event detection...)
		canvas.addKeyListener(new KeyHandler());
		add(canvas);

		// Cheap way to put some text onto the screen...
		add(new Label("Try the File menu..."));
		add(new Label("Then, press Ctrl+X to exit"));
    }

    // Set up the File Menu
    private void initFileMenu() {
        Menu fileMenu = new Menu("File");
        mBar.add(fileMenu);

        Menu sub1Menu = new Menu("Sub 1");
        fileMenu.add(sub1Menu);

		MenuItem item1 = new MenuItem("One");
		sub1Menu.add(item1);
		
		MenuItem item2 = new MenuItem("Two");
		sub1Menu.add(item2);

        MenuItem otherItem = new MenuItem("Other");
        fileMenu.add(otherItem);

        Menu sub2Menu = new Menu("Sub 2");
        fileMenu.add(sub2Menu);

		MenuItem item3 = new MenuItem("Three");
		sub2Menu.add(item3);

		Menu sub3Menu = new Menu("Sub 3  ");
		sub2Menu.add(sub3Menu);

		MenuItem item6 = new MenuItem("Six");
		sub3Menu.add(item6);

		sub3Menu.addSeparator();

		MenuItem item7 = new MenuItem("Seven");
		sub3Menu.add(item7);

		MenuItem item5 = new MenuItem("Five");
		sub2Menu.add(item5);

        fileMenu.addSeparator();

        MenuItem exitItem = new MenuItem("Exit");
        exitItem.addActionListener(new ActionListener() {
	        public void actionPerformed(ActionEvent e) {
	            System.exit(0);
	    	}
		});
        fileMenu.add(exitItem);
    }

	// Key handler for detection of Ctrl-X
	private class KeyHandler extends KeyAdapter {
		public void keyTyped(KeyEvent e) {
			if (e.getModifiers() == InputEvent.CTRL_MASK) {			// Ctrl key
				if (((int) e.getKeyChar()) == ('x' - 'a' + 1)) {	// Ctrl+X
					// Consume the event so that someone above (Windows) doesn't take it...
			  		e.consume();
					System.out.println("You pressed Ctrl-X.");
					System.out.println("This application will now exit...");
					System.out.println();
					System.exit(0);
				}
			} 
		}
	}

    public static void main(String[] args) {
        smd = new SubMenusDemo();
        smd.setSize(WIDTH, HEIGHT);
        smd.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                System.exit(0);
            }
        });
        smd.setVisible(true);
    }

    private static final int WIDTH  = 250;
    private static final int HEIGHT = 250;
    private static SubMenusDemo smd;
    private MenuBar mBar = new MenuBar();
    private Canvas canvas = new Canvas();
}
